/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org view-source front-end.
 *
 * The Initial Developer of the Original Code is mozilla.org.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jeroen Groenenboom <jagrboom@zonnet.nl> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var bMHPrefs = {

defaults: [{name: "engine", type: 64, value: 0 },
	  { name: "table-main-cellpadding", type: 64, value: 5 },
	  { name: "table-column-cellspacing", type: 64, value: 5 },
	  { name: "nrOfColumns", type: 64, value: 4 },
	  { name: "maxNameLength", type: 64, value: 25 },
	  { name: "stylesheet", type: 32, value: "body {\n" +
	      "background-color: #ffffcc;\n" + 
		  "font-family: 'trebuchet ms', arial, helvetica, sans-serif;\n}\n" +
		  ".table-main { background-color: #cccc99; }\n" +
		  "/* .table-column {} */\n" +
		  ".table-folder { background-color: #ffccff; }\n" +
		  ".table-folder th {\n" +
		  "background-color: #ff9966;\n" +
		  "color: #ffffff;\n" +
		  "font-size: .8em\n}\n" +
		  "a { color: #000000;\n" +
		  "text-decoration: none;\n" +
		  "font-size: .8em\n}\n" +
		  "a:hover {\ntext-decoration: underline;\n" +
		  "color: 996600;\n}\n" },
	      { name: "exclude", type: 128, value: true },
	      { name: "inOrExcludedFolders", type: 32, value: "" }],

engines: [{name: "Google", value: "www.google.com/search?q=" },
	 { name: "Yahoo", value: "search.yahoo.com/bin/search?p=" },
	 { name: "Ask Jeeves", value: "web.ask.com/web?q=" },
	 { name: "dmoz.org", value: "search.dmoz.org/cgi-bin/search?search=" },
	 { name: "None", value: "none" }],

init: function() {
	  var branch = Components.classes["@mozilla.org/preferences-service;1"].
	      getService( Components.interfaces.nsIPrefService ).
	      getBranch( "bookmarkshome." );
	  var dflt;
	  for( var i = 0; i < bMHPrefs.defaults.length; i++ ) {
	      dflt = bMHPrefs.defaults[i];
	      if( ! branch.prefHasUserValue( dflt.name )) {
		  bMHPrefs.setPref( dflt.name, dflt.type, dflt.value );
	      }
	  }
      },

getDefault: function( index ) {
		return bMHPrefs.defaults[index];
	    },

getNrOfPrefs: function() {
		  return bMHPrefs.defaults.length;
	      },

getPref: function( name ) {
	     var branch = Components.classes["@mozilla.org/preferences-service;1"].
		 getService( Components.interfaces.nsIPrefService ).
		 getBranch( "bookmarkshome." );
	     var type = branch.getPrefType( name );
	     if( type == branch.PREF_STRING ) {
		 return branch.getCharPref( name );
	     }
	     else if( type == branch.PREF_INT ) {
		 return branch.getIntPref( name ); 
	     }
	     else if( type == branch.PREF_BOOL ) {
		 return branch.getBoolPref( name );
	     }
	 },

setPref: function( name, type, value ) {
	     var branch = Components.classes["@mozilla.org/preferences-service;1"].
		 getService( Components.interfaces.nsIPrefService ).
		 getBranch( "bookmarkshome." );
	     if( type == branch.PREF_STRING ) {
		 branch.setCharPref( name, value );
	     }
	     else if( type == branch.PREF_INT ) {
		 branch.setIntPref( name, value ); 
	     }
	     else if( type == branch.PREF_BOOL ) {
		 branch.setBoolPref( name, value );
	     }
	 },

engineOptions: function( window ) {
		   // last engine is none, should not be visible on page
		   var length = bMHPrefs.engines.length;
		   if( window == "main" ) {
		       length--;
		   }
		   var options = "";
		   for( var i = 0; i < length; i++ ) {
		       options += '\n<option value="' + bMHPrefs.engines[i].value +
			   '">' + bMHPrefs.engines[i].name + '</option>';
		   }
		   return options;
	       },

internetSearch: function() {
		    var engineSelect = document.getElementById( "engineSelect" );
		    var engine = engineSelect.options[engineSelect.selectedIndex].value;
		    var query = encodeURI( document.getElementById( "queryInput" ).value );
		    window.location = ( "http://" + engine + query );
		    // return false to prevent form from being submitted
		    return false;
		},

binarySearch: function( target, array ) {
		  var found = false;
		  var first = 0, last = array.length - 1, temp, mid;
		  while (( !found ) && ( first <= last )) {
		      temp = first + last;
		      // integer division
		      mid = ( temp - ( temp % 2 )) / 2;
		      if( target == array[mid] ) {
			  found = true;
		      }
		      else if( target < array[mid] ) {
			  last = mid - 1;
		      }
		      else {
			  first = mid + 1;
		      }
		  }
		  return( found ? mid : -1 ); 
	      }, 

isExcludedFolder: function( folderString, exclude, inOrExcludedFolders ) {
		   var index = bMHPrefs.binarySearch( folderString, inOrExcludedFolders ); 
		   var isInOrExcluded = ( index >= 0 );
		   return exclude == isInOrExcluded ? true : false;
	       },
		   
}


