/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org view-source front-end.
 *
 * The Initial Developer of the Original Code is mozilla.org.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jeroen Groenenboom <jagrboom@zonnet.nl> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var bMHPrefsWindow = {

init: function() {
	  var field;
	  var prefIndex;
	  // engine
	  field = document.getElementById( "engine" );
	  field.selectedIndex = bMHPrefs.getPref( "engine" );
	  // text fields
	  for( prefIndex = 1; prefIndex < bMHPrefs.getNrOfPrefs()-2; prefIndex++ ) {
	      field = document.getElementById( bMHPrefs.getDefault( prefIndex ).name );
	      field.value = bMHPrefs.getPref( bMHPrefs.getDefault( prefIndex ).name );
	  }
	  // exclude
	  field = document.getElementById( "exclude" );
	  field.selectedIndex = ( bMHPrefs.getPref( "exclude" ) ? 0 : 1 );
	  
	  // in- or excluded folders
	  bMHPrefsWindow.writeInOrExcludeDoc( bMHPrefs.getPref( "exclude" ), 
		  bMHPrefs.getPref( "inOrExcludedFolders" ));
      },

writeInOrExcludeDoc: function( exclude, inOrExcludedString ) {
		     var doc = inOrExcludeFrame.document;
		     var inOrExcludedFolders = inOrExcludedString.split( "|" ); 
		     doc.writeln( '<html>\n<head>' +
			     '\n<script type="text/javascript"' +
			     'src="chrome://bookmarkshome/content/bookmarksHomePrefsWindow.js"></script>' +  
			     '\n</head>\n<body>\n<tt>\n<form id="inOrExcludeForm">' );
		     var inputs = window.opener.document.getElementsByName( "folderInput" );
		     var ancestorsArray = new Array( inputs.length );
		     var i;
		     for( i = 0; i < inputs.length; i++ ) {
			 ancestorsArray[i] = inputs[i].value;
		     }
		     ancestorsArray.sort();
		     var ancestors, isChecked, isExcludedFolder, j;
		     for( i = 0; i < ancestorsArray.length; i++ ) { 
			 ancestors = ancestorsArray[i].split( "," );
			 for( j = 1; j < ancestors.length; j++ ) {
			     doc.write( '&nbsp;&nbsp;&nbsp;&nbsp;' );
			 }
			 isExcludedFolder = bMHPrefs.isExcludedFolder( ancestorsArray[i], 
				 exclude, inOrExcludedFolders );
			 isChecked = ( exclude == isExcludedFolder ? "checked" : "" );
			 doc.writeln( '\n<input type="checkbox" name="inOrExcludeCheckbox"' +
				 isChecked + '" value="' + ancestorsArray[i] + 
				 '" onchange="bMHPrefsWindow.checkSubfolders(' + i + ');">' + 
				 ancestors[ancestors.length-1] + '<br>' );
		     }
		     doc.writeln( '\n</form>\n</tt>\n</body>\n</html>' );
		     doc.close();
		 },

reset: function() {
	   var field;
	   var prefIndex = 0;
	   // engine
	   field = document.getElementById( "engine" );
	   field.selectedIndex = bMHPrefs.getDefault( prefIndex ).value;
	   // text fields
	   for( prefIndex = 1; prefIndex < bMHPrefs.getNrOfPrefs()-2; prefIndex++ ) {
	       field = document.getElementById( bMHPrefs.getDefault( prefIndex ).name );
	       field.value = bMHPrefs.getDefault( prefIndex ).value;
	   }
	   // exclude
	   field = document.getElementById( "exclude" );
	   field.selectedIndex = ( bMHPrefs.getDefault( prefIndex ).value == 0 );
	   prefIndex++;
	   // in- or excluded folders
	   bMHPrefsWindow.writeInOrExcludeDoc( bMHPrefs.getDefault( prefIndex-1 ).value,
		   bMHPrefs.getDefault( prefIndex ).value );
       },

close: function() {
	   window.close();
       },

apply: function() {
	   var prefs = new Array( bMHPrefs.getNrOfPrefs() );
	   var prefIndex = 0;
	   var field, type, value;
	   // engine
	   field = document.getElementById( "engine" ),
	   value = field.selectedIndex;
	   prefs[prefIndex] = { name: "engine", type: 64, value: value };
	   // text fields
	   for( prefIndex = 1; prefIndex < prefs.length-2; prefIndex++ ) {
	       field = document.getElementById( bMHPrefs.getDefault( prefIndex ).name );
	       type = bMHPrefs.getDefault( prefIndex ).type;
	       value = bMHPrefsWindow.parseValue( field.value, bMHPrefs.getDefault( prefIndex ) ); 
	       prefs[prefIndex] = { name: field.id, type: type, value: value };
	       if( value == -1 ) {
		   alert( field.id + ' does not have a proper value' );
		   return;
	       }
	   }
	   // exclude 
	   field = document.getElementById( "exclude" );
	   value = ( field.selectedIndex == 0 );
	   prefs[prefIndex] = { name: "exclude", type: 128, value: value };
	   // in- or excluded folders
	   prefIndex++;
	   var inOrExcludedString = "";
	   var checkboxes = inOrExcludeFrame.document.getElementsByName( "inOrExcludeCheckbox" );
	   for( var i = 0; i < checkboxes.length; i++ ) {
	       if( checkboxes[i].checked ) {
		   inOrExcludedString += ( "|" + checkboxes[i].value );
	       }
	   }
	   if( inOrExcludedString.length > 0 ) {
	       // remove first bar
	       inOrExcludedString = inOrExcludedString.substr( 1 );
	   }
	   prefs[prefIndex] = { name: "inOrExcludedFolders", type: 32, value: inOrExcludedString };
	   // set preferences
	   for( prefIndex = 0; prefIndex < prefs.length; prefIndex++ ) {
	       bMHPrefs.setPref( prefs[prefIndex].name, prefs[prefIndex].type, prefs[prefIndex].value );
	   }
	   window.opener.location.reload();
       },

checkSubfolders: function( startIndex ) {
		     // called from inOrExcludeFrame
		     var checkboxes;
		     if( parent.document.getElementById( "subfolderCheckbox" ).checked ) {
			 checkboxes = document.getElementsByName( "inOrExcludeCheckbox" );
			 var regExp = new RegExp( "^" + checkboxes[startIndex].value );
			 var i = startIndex + 1;
			 while( i < checkboxes.length && regExp.test( checkboxes[i].value )) {
			     checkboxes[i].checked = checkboxes[startIndex].checked;
			     i++;
			 }
		     }
		 },


parseValue: function( value, dflt ) {
		if( dflt.type == 64 ) {
		    value = parseInt( value );
		    if( isNaN( value ) ||
			    value < 0 ||
			    ( value == 0 && 
			      (dflt.name == "nrOfColumns" || 
			       dflt.name == "maxNameLength" ))) {
			return -1;
		    }
		}
		return value;
	    },
}



